*** Purpose: Create dataset of population, death rates, hospitalization rates, and 
*** 		 ICU rates by age group. This dataset will be merged with total deaths by channel
***			 (direct or overflow) to generate age distributions of deaths.

cap log close
clear

pause on

set scheme s2mono

*** setup
* global ROOT "/Users/`c(username)'/Dropbox/Coronavirus/Public"

cd "$ROOT/Code"
local all_data "$ROOT/Data"

*** options
local epa_vsl = 11.5e6 // $11.5 million is EPA VSL for prime-age worker, in 2020$



* import life expectancy + P(death) by age from CDC
import excel "`all_data'/us_lifeexp.xlsx", sheet("data") cellrange(A3:J104) firstrow clear
keep A ex qx
rename ex life_exp_remain
lab var qx "Prob of death from age x to x+1"
gen age = _n-1
drop A

tempfile temp1
save "`temp1'", replace


* import population at each age. These are 2017 estimates based on 2010 Census.
import excel "`all_data'/census_pop.xlsx", sheet("Sheet1") cellrange(A2:B89) clear
rename A age
rename B pop_t

drop if _n >= _N-1 //i.e. drop last observation, which had median age
replace age = "85" if age == "85+" // age 85 includes anyone older
destring age, replace

* merge in life exp and P(death) by age
merge 1:1 age using "`temp1'", assert(2 3) nogen

* Census does not give age-specific populations for 85+. Use life table to impute.
local pop85plus = pop_t[86] //save total actual population of 85+
// impute: age t pop = (age t-1 pop) * Prob(reach age t | reached age t-1)
replace pop_t = pop_t[_n-1]*(1-qx[_n-1]) if age >= 85
// adjust to make sure total population is same as what Census reports
total pop_t if age >= 85 //6543333
replace pop_t = pop_t * `pop85plus'/6543333

tempfile temp2
save "`temp2'", replace


* finally, import Imperial College data, merge to others
//From Table 1 of IC paper
import excel "`all_data'/imperial_data.xlsx", sheet("Imperial study") firstrow clear
lab var fatality_rate_pct "Infection fatality rate"
lab var hosp_rate_pct "Percent of symptomatic cases requiring hospitalization"
lab var icu_rate_pct "Percent of hospitalized cases requiring ICU"
merge 1:1 age using "`temp2'", assert(3) nogen

*** compute mean life expectancy by age group j
bysort age_cat (age): egen pop_j = total(pop_t) // compute total population in each age category (pop_j)
gen popshare = pop_t/pop_j // compute population weights (pop_t/pop_j)
gen to_collapse = life_exp_remain * popshare

tempfile tempdata
save "`tempdata'", replace	

*** also compute Murphy-Topel mean VSL by age group before collapsing, bc it is yearly
*import Murphy-Topel VSLs, obtained from authors. Take simple average of men and women by age.
import excel "`all_data'/murphy_topel.xlsx", sheet("Sheet1") firstrow clear
drop if missing(Age)
rename Age age
gen vsl_murphy = (Males + Females)/2 // avg across male/female
keep age vsl_murphy
tempfile tempmurph
save "`tempmurph'", replace

*merge murphy_topel VSL into original data by age
use "`tempdata'", clear
merge 1:1 age using "`tempmurph'"
// drop VSLs over 100; implicitly assume that all people 100+ get 100-year-old's VSL
// VSL at age 100 is $174,133. VSL at age 110 is $55,255
keep if _merge == 3 
drop _merge

* then scale so adult average equals EPA's VSL
summ vsl_murphy if age >= 18 [aw = pop_t]
replace vsl_murphy = (vsl_murphy/`r(mean)')*`epa_vsl'

* generate VSL * weight var, similar to for life exp, before summing within a group
gen to_collapse_vsl = vsl_murphy * popshare

* Finally, sum by IC age group
collapse (sum) mean_life_exp=to_collapse vsl_mt=to_collapse_vsl, ///
	by(age_cat fatality_rate_pct hosp_rate_pct icu_rate_pct pop_j)

gen to_merge = 1 // variable always = 1 so we can merge into other data

*** compute constant VSL as well
gen vsl_epa = `epa_vsl' // same for all 
	
save "`all_data'/age_bracket_data.dta", replace
