*** Purpose: Compute deaths averted by avoiding an overloading of the health system.
*** 			Generate Figure 2.
*** 
*** Note: Unless otherwise indicated, all parameters are inferred visually from the
*** 	Imperial College paper (Ferguson et al. 2020)
*** 

cap log close
clear

set more off
pause on

set scheme s2mono
graph set window fontface "Arial"

set seed 38596

*** setup
*global ROOT "/Users/`c(username)'/Dropbox/Coronavirus/Public"

cd "$ROOT/Code"
local internal_data "$ROOT/Data"
local figs = "$ROOT"

*** switches
local make_distributions = 1
	local plot = 1
	
*** parameters (_0 means no distancing, _1 means with moderate distancing)
local peak_beds_0 = 225 * (320e6/1e5) // peak ICU beds occupied without distancing (Ferguson et al. Appendix figure)
local days_to_peak_0 = 57 // days from start of distancing to peak (Ferguson et al. Appendix figure)
local peak_beds_1 = `peak_beds_0' * .35 // peak is approx. two-thirds lower wtih mitigation
local days_to_peak_1 = `days_to_peak_0' * (70/50) // multiply by ratio of days to peak with mitigation vs no policy in GB from Figure 2 of Ferguson et al.

local max_beds = 14 * (320e6/1e5) // US surge ICU beds (Ferguson et al. Appendix Figure)
local days_in_icu = 10 // 10 days in ICU if ICU required (assumption in Ferguson et al)
local max_patients = `max_beds'/`days_in_icu' // number of new patients in USA that can enter ICU on a day

local nonicu_death_rate = 0.9 // death rate for those turned away from ICU, assumed .9 by authors
local icu_death_rate = 0.5 // ICU death rate, assumed in Ferguson et al.

local sds_to_peak = 3.5 // ASSUMPTION: start of plot, to peak, is 3.5 sd. This matches SDs to peak in direct deaths calculation, 
						// 				which is calibrated to total deaths of 2.2mn with no distancing (see file 3).

local noise_sd = 100 // SD of noise


if `make_distributions' == 1 {

	* empty dataset
	import excel "`internal_data'/empty.xlsx", sheet("Sheet1") clear // make an empty dataset in excel, import
	drop if _n != 1
	expand 180 // days. Assume each month has 30 days, we will model March 1 to September 1 (almost no cases in September in Ferguson et al.)
	rename A days
	replace days = _n-30 // day 0 is April 1, when normal dist visually appears to start in Ferguson paper
	
	* generate max patient line
	gen max_patients = `max_patients'

	foreach x in 0 1 {
		* generate histograms 
		local sd_`x' = `days_to_peak_`x''/`sds_to_peak' // assume days to peak = 3.5 standard deviations.
		gen height_`x' = normalden(days, `days_to_peak_`x'', `sd_`x'')

		* store peak
		summ height_`x', d
		return list
		
		* rescale by peak height to get "new people in ICU" curve
		* interp: top of histogram should be peak number of new patients allowed, which is approx peak beds/number of days
		gen icu_new_patients_`x' = (height_`x'/r(max))*(`peak_beds_`x''/`days_in_icu')
		* add noise 
		replace icu_new_patients_`x' = max(icu_new_patients_`x' + rnormal(0,`noise_sd'),0)
		
		* compute extra patients each day who do not get beds
		gen icu_surplus_patients_`x' = max(icu_new_patients_`x'-max_patients,0)
		
		* compute share of surplus patients that die (that would not have otherwise)
		gen deaths_hosp_`x' = (icu_surplus_patients_`x') * (`nonicu_death_rate'-`icu_death_rate')
	}
		
	drop height*
	
	if `plot' == 1 { // Make figure 2
		* plot

		gen first = 0
		replace first = max_patients if days <= 36
		replace first = icu_new_patients_1 if days > 36
		
		gen second = 0
		replace second = icu_new_patients_1 if days <=80
		replace second = icu_new_patients_0 if days >80

		gen third = 0
		replace third = icu_new_patients_0 if days < 96
		replace third = max_patients if days >=96

		format first %10.0gc

		graph twoway (rarea first icu_new_patients_0 days if days > 18 & days < 81, color(red*0.7)) ///
					(rarea max_patients second days if days > 37 & days < 96, color(orange*0.7)) ///
					(rarea third icu_new_patients_1 days if days > 80 & days < 123, color(yellow*0.7)) ///
					(line icu_new_patients_0 days, color(red) lpattern(solid)) (line icu_new_patients_1 days, color(blue) lpattern(solid)) ///
					 (line max_patients days, color(black) lpattern(dash)), ///
						 ytitle("New Patients Requiring ICU Care by Day" "") ///
						 graphregion(color(white)) bgcolor(white) plotregion(color(white)) ///
						legend(label(4 "No Policy") label(5 "Mitigation Social Distancing") label(6 "US Surge ICU Capacity")  order(4 5 6) cols(1) region(lcolor(white))) ///
						xsize(12) ysize(8) ylabel(, nogrid angle(45) labsize(medsmall)) xtitle("") ///
						xlabel(-30 "Mar 1" 0 "Apr 1" 30 "May 1" 60 "Jun 1" 90 "Jul 1" 120 "Aug 1" 150 "Sep 1", labsize(medsmall))

		graph export "`figs'/fig2.pdf", replace

	}
			
	* Now we have deaths by day under each policy.
	* Deaths can be distributed to different age groups j ...
	* where the weight = population * P(hospitalized|symptoms) * P(ICU|hospitalized)
	tempfile temp1 
	save "`temp1'"
	
	use "`internal_data'/age_bracket_data.dta", clear
	
	* generate weights
	gen wtvar = pop_j * hosp_rate_pct * icu_rate_pct
	summ wtvar, d
	local wtvar_tot = r(sum)
	replace wtvar = wtvar/`wtvar_tot'
	keep age_cat wtvar
	
	* expand by number of days
	expand 180
	sort age_cat
	gen id = _n
	gen days = mod(_n, 180)
	replace days = 180 if days == 0
	replace days = days - 30 // should go from -30 to 150, not 0 to 180
	drop id
	
	* merge in deaths data
	merge m:1 days using "`temp1'"
	order days age_cat
	sort age_cat days
	drop _merge
	
	* Multiply ICU cases + deaths by weights to distribute across age groups
	foreach var of varlist icu_new* icu_surplus* deaths_hosp* {
		replace `var' = `var' * wtvar
	}
	
	keep days age_cat deaths*
	gen channel = "crowding"
	order channel days age_cat deaths*
	
	save "`internal_data'/deaths_crowding_panel.dta", replace
	
}












