*** Purpose: Compute "direct deaths" averted by slowing the spread of the virus.
*** 			Generate Figure 1.
*** Note: All parameters visually inferred from Ferguson et al. (2020) unless otherwise indicated.

cap log close
set more off
clear

pause on

set scheme s2mono
graph set window fontface "Arial"

*** setup
*global ROOT "/Users/`c(username)'/Dropbox/Coronavirus/Public"

cd "$ROOT/Code"
local internal_data "$ROOT/Data"
local figs = "$ROOT"

set seed 022299

*** switches
local make_distributions = 1
	local total_death_check = 0
local plot = 1 // generate figure 3

*** parameters (0 means no distancing, 1 means yes distancing)
local peak_deaths_0 = 17 * (320e6/1e5) // peak deaths/day without distancing (Fig 1 of Ferguson et al.)
local days_to_peak_0 = 57 // days to peak (visually inferred from Fig 1 of Ferguson)

local peak_deaths_1 = `peak_deaths_0' * .35 // assume peak deaths fall in same ratio to critical care beds, as reported
local days_to_peak_1 = `days_to_peak_0' * (70/50) // multiply by ratio of days to peak with vs without distancing from GB figure

local sds_to_peak = 3.5 // Assumption: start of distancing, to peak, is 3.5 standard deviations. Calibrated so total deaths averted match 1.1mn reported in paper. 

local noise_sd = 100 // add noise 


if `make_distributions' == 1 {

	* empty dataset
	import excel "`internal_data'/empty.xlsx", sheet("Sheet1") clear // make an empty dataset in excel, import
	drop if _n != 1
	expand 180
	rename A days
	replace days = _n-30
	
	foreach x in 0 1 {
		* generate histograms 
		local sd_`x' = `days_to_peak_`x''/`sds_to_peak' // assume days to peak = 3.5 standard deviations.
		gen height_`x' = normalden(days, `days_to_peak_`x'', `sd_`x'')
		
		* store peak
		summ height_`x', d
		return list
		
		* rescale by peak height to get "deaths/day"
		* interp: top of histogram should be peak number of deaths
		gen deaths_spread_`x' = (height_`x'/r(max))*(`peak_deaths_`x'') 
		
		* add noise 
		replace deaths_spread_`x' = max(deaths_spread_`x' + rnormal(0,`noise_sd'),0)
		
	}
	
	drop height* 
	
	*** Check that deaths are 2.2mn with no policy / 1.1mn with moderate distancing
	if `total_death_check' == 1 {
		preserve
			collapse (sum) deaths*
			list
			pause
		restore
	}
			
	*** plot
	
	* plot
	if `plot' == 1 {

		format deaths_spread_0 %10.0gc
		format deaths_spread_1 %10.0gc

		graph twoway (line deaths_spread_0 days, color(red) lpattern(solid)) (line deaths_spread_1 days, color(blue) lpattern(solid)) , ///
			 ytitle("Deaths Per Day" "", margin(vsmall) size(medium)) xscale(range(-30 150)) ///
			 xlabel(-30 "Mar 1" 0 "Apr 1" 30 "May 1" 60 "Jun 1" 90 "Jul 1" 120 "Aug 1" 150 "Sep 1", labsize(small)) ///
			 graphregion(color(white)) bgcolor(white) plotregion(color(white)) title(Panel B: This Paper) ///
			legend(label(1 "No Policy") label(2 "Mitigation Social Distancing") cols(1) region(lcolor(white) color(none)) size(medsmall) position(0) bplacement(neast)) ///
			xsize(10) ysize(8) ylabel(, nogrid angle(45) labsize(medsmall)) xtitle("") name(g2, replace)
													
		graph export "`figs'/fig1b.pdf", replace

	}	
	
	tempfile temp1 
	save "`temp1'"
	
	*** DISTRIBUTE BY AGES
	use "`internal_data'/age_bracket_data.dta", clear
		
	* generate weights
	* weight = population * P(infection) * fatality rate , but we assume that P(infection) is fixed across age groups
	gen wtvar = pop_j * fatality_rate_pct // note that weight var here is different than for overflow deaths
	summ wtvar, d
	local wtvar_tot = r(sum)
	replace wtvar = wtvar/`wtvar_tot'
	keep age_cat wtvar
	
	* expand by number of days
	expand 180
	sort age_cat
	gen id = _n
	gen days = mod(_n, 180)
	replace days = 180 if days == 0
	replace days = days-30
	drop id
	
	* merge in deaths data
	merge m:1 days using "`temp1'"
	order days age_cat
	sort age_cat days
	drop _merge
	
	* Multiply deaths by weight to distribute across age groups
	foreach var of varlist deaths_spread* {
		replace `var' = `var' * wtvar
	}
	
	keep days age_cat deaths*
	gen channel = "spread"
	order channel days age_cat deaths*
		
	save "`internal_data'/deaths_spread_panel.dta", replace
	
}


if `plot' == 1 { // reconstruct Figure 1 of Ferguson et al. (2020) for comparison

	* nonparametrically extracted points from Figure 1 of Ferguson et al. (2020) using online tool
	import delimited "`internal_data'/extracted_points.csv", clear 

	rename v1 days
	rename v2 deaths

	sort days
	gen diff = days - days[_n-1] if _n!=1
	drop if diff==0

	replace deaths = deaths*(320000000/100000) // rescale to get total US deaths

	format deaths %10.0gc

	*replace days = trunc(days)
	*bysort days: keep if _n==1

	graph twoway (line deaths days if days < 61, color(red)), ytitle("Deaths Per Day", margin(vsmall) size(medium)) ///
		xlabel(0 "Mar 1" 10 "Apr 1" 20 "May 1" 30 "Jun 1" 40 "Jul 1" 50 "Aug 1" 60 "Sep 1") ///
		graphregion(color(white)) bgcolor(white) plotregion(color(white)) name(g1, replace) title(Panel A: Ferguson et al. (2020) Original Data) ///
		xlabel( , labsize(small)) ylabel(, nogrid angle(45) labsize(medsmall)) xsize(10) ysize(8) xscale(range(0 60)) xtitle("")

	graph export "`figs'/fig1a.pdf", replace
}
	
	
graph combine g1 g2, cols(1) imargin(top_bottom) graphregion(color(white)) plotregion(color(white)) ///
		xsize(10) ysize(8)
	
graph export "`figs'/fig1.pdf", replace
	
	
	
	
	

	
	
