*** Purpose: Create Table 1 that shows total deaths by age group, VSL, and benefits

cap log close
clear
set more off

pause on

set scheme s2mono
graph set window fontface "Times New Roman"


*** setup
*global ROOT "/Users/`c(username)'/Dropbox/Coronavirus/Public"

cd "$ROOT/Code"
local internal_data "$ROOT/Data"
local tables "$ROOT"

local prep_data = 1
	local us_hhs = 120e6 // Approximate # of us households
local make_table = 1


*** Start

if `prep_data' == 1 {

	use "`internal_data'/deaths_benefits_panel.dta", clear
	
	* collapse to age group level
	collapse (sum) deaths_* tot_deaths* benefits_mt (first) pop_j vsl_mt, by(age_cat)
	
	* First: compute total death rates over all days with and without distancing
	* idea: people are trading off this death rate against their economic well-being.
	* Second: Compute diff in death rate delivered by distancing
	* Third: Multiply by age-group population to get diff in deaths, by channel
	
	foreach stem in "spread" "hosp" { // spread is direct, hosp is overflow
		gen rate_`stem'_0 = (deaths_`stem'_0 / pop_j)
		gen rate_`stem'_1 = (deaths_`stem'_1 / pop_j)
		gen rate_`stem'_diff = rate_`stem'_0 - rate_`stem'_1 
		
		gen deaths_`stem'_diff = rate_`stem'_diff * pop_j
	}
	
	* Compute total difference in deaths
	gen tot_deaths_diff = deaths_spread_diff + deaths_hosp_diff
	assert abs(tot_deaths_diff - (tot_deaths_0 - tot_deaths_1)) < 1 // roundabout calculations work!
		
	* setup for table
	keep age_cat pop_j rate_spread_0 rate_spread_1 rate_spread_diff deaths_spread_diff ///
				rate_hosp_0 rate_hosp_1 rate_hosp_diff deaths_hosp_diff ///
				tot_deaths_diff vsl_mt benefits_mt
				
	order age_cat pop_j rate_spread_0 rate_spread_1 rate_spread_diff deaths_spread_diff ///
				rate_hosp_0 rate_hosp_1 rate_hosp_diff deaths_hosp_diff ///
				tot_deaths_diff vsl_mt benefits_mt
					 
}

if `make_table' == 1 { // make table 1

	*** Prepare table values
	
	* add row with totals
	insob 2 _N, after
	replace age_cat = age_cat[_n-1] + 1 if missing(age_cat)
	foreach x of varlist deaths_* tot_deaths_diff benefits_mt {
		summ `x', d
		replace `x' = `r(sum)' if _n == _N
	}
	
	* format age_cat
	gen age_label = ""
	replace age_label = "0-9" if age_cat == 0
	replace age_label = "10-19" if age_cat == 1
	replace age_label = "20-29" if age_cat == 2
	replace age_label = "30-39" if age_cat == 3
	replace age_label = "40-49" if age_cat == 4
	replace age_label = "50-59" if age_cat == 5
	replace age_label = "60-69" if age_cat == 6
	replace age_label = "70-79" if age_cat == 7
	replace age_label = "80+" if age_cat == 8
	replace age_label = "US Total" if age_cat == 10
	order age_label
	drop age_cat
		
	* rounding
	foreach x of varlist pop_j vsl_mt {
		replace `x' = round(`x'/1e6,.1) // millions
		format `x' %9.1fc
	}
	foreach x of varlist rate* { // in pct
		replace `x' = round(`x'*100, .001)
		format `x' %9.3fc
	}
	foreach x of varlist deaths* tot_deaths* {
		replace `x' = round(`x', 1)
		format `x' %9.0fc
	}
	replace benefits_mt = round(benefits_mt/1e12, .01)
	format benefits_mt %9.2fc
	
	* to string, bold last line
	tostring pop_j-benefits_mt, replace force usedisplayformat
	foreach x of varlist * {
		replace `x' = "" if `x' == "."
		replace `x' = "\textbf{" + `x' + "}" if _n == _N & `x' != ""
	}

	* prepare to output:
	texsave * using "`tables'/table1.tex", replace ///
		title("\bf Social Distancing Benefits Americans By Lowering Chance of Death") frag nofix location(H) rowsep(1mm) nonames size(small) ///
		headerlines("& \multicolumn{1}{c}{Population} & \multicolumn{4}{c}{Direct Deaths} & \multicolumn{4}{c}{Overflow Deaths} & \multicolumn{3}{c}{All} " ///
					" \cmidrule(lr){2-2} \cmidrule(lr){3-6} \cmidrule(lr){7-10} \cmidrule(lr){11-13}" ///
					"  & & \multicolumn{1}{c}{No} & Mitigation & & & \multicolumn{1}{c}{No} & Mitigation & & & & & " ///
					"  & & Policy & Distancing & \multicolumn{2}{c}{Difference} & Policy & Distancing & \multicolumn{2}{c}{Difference} & & & " ///
					" \cmidrule(lr){3-3} \cmidrule(lr){4-4} \cmidrule(lr){5-6} \cmidrule(lr){7-7} \cmidrule(lr){8-8} \cmidrule(lr){9-10}  " ///
					" & \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2a)} & \multicolumn{1}{c}{(2b)} & \multicolumn{1}{c}{(2c)} & \multicolumn{1}{c}{(2d)} & \multicolumn{1}{c}{(3a)} & \multicolumn{1}{c}{(3b)} & \multicolumn{1}{c}{(3c)} & \multicolumn{1}{c}{(3d)} & \multicolumn{1}{c}{(4a)} & \multicolumn{1}{c}{(4b)} & \multicolumn{1}{c}{(4c)}" ///
					" \multicolumn{1}{c}{Age} & \multicolumn{1}{c}{US pop in} & \multicolumn{1}{c}{Pct} & \multicolumn{1}{c}{Pct} & \multicolumn{1}{c}{Pct} & \multicolumn{1}{c}{Death} & \multicolumn{1}{c}{Pct} & \multicolumn{1}{c}{Pct} & \multicolumn{1}{c}{Pct} & \multicolumn{1}{c}{Death} & \multicolumn{1}{c}{Death} & \multicolumn{1}{c}{VSL in} & \multicolumn{1}{c}{Benefits in}" ///
					" \multicolumn{1}{c}{group} & \multicolumn{1}{c}{millions} & \multicolumn{1}{c}{of pop} & \multicolumn{1}{c}{of pop} & \multicolumn{1}{c}{of pop}  & \multicolumn{1}{c}{count}  & \multicolumn{1}{c}{of pop} & \multicolumn{1}{c}{of pop} & \multicolumn{1}{c}{of pop} & \multicolumn{1}{c}{count} & \multicolumn{1}{c}{count} & \multicolumn{1}{c}{million USD} & \multicolumn{1}{c}{trillion USD} " ) ///
		align(lrrrrrrrrrrrr) bold("Benefits") width(1.07\linewidth)

}
























